@@ -27,6 +27,8 @@
 #include "enums.h"
 #include "kgapicalendar_export.h"
 
+#include <QScopedPointer>
+
 namespace KGAPI2 {
 
 /**
@@ -97,7 +99,7 @@ class KGAPICALENDAR_EXPORT EventModifyJob : public KGAPI2::ModifyJob
 
   private:
     class Private;
-    Private * const d;
+    QScopedPointer<Private> const d;
     friend class Private;
 
 };
