@@ -128,11 +128,11 @@ QString Job::Private::parseErrorMessage(const QByteArray &json)
         QVariantMap map = document.toVariant().toMap();
         QString message;
 
-        if (map.contains(QStringLiteral("error"))) {
+        if (map.contains(QLatin1String("error"))) {
             map = map.value(QStringLiteral("error")).toMap();
         }
 
-        if (map.contains(QStringLiteral("message"))) {
+        if (map.contains(QLatin1String("message"))) {
             message.append(map.value(QStringLiteral("message")).toString());
         } else {
             message = QLatin1String(json);
@@ -332,7 +332,7 @@ void Job::Private::_k_dispatchTimeout()
     QUrl url = authorizedRequest.url();
     QUrlQuery standardParamQuery(url);
     if (!fields.isEmpty()) {
-        standardParamQuery.addQueryItem(Job::StandardParams::Fields, fields.join(QStringLiteral(",")));
+        standardParamQuery.addQueryItem(Job::StandardParams::Fields, fields.join(QLatin1Char(',')));
     }
 
     if (!standardParamQuery.hasQueryItem(Job::StandardParams::PrettyPrint)) {
@@ -470,7 +470,7 @@ void Job::setFields(const QStringList &fields)
 }
 
 QString Job::buildSubfields(const QString &field, const QStringList &fields) {
-    return QStringLiteral("%1(%2)").arg(field).arg(fields.join(QStringLiteral(",")));
+    return QStringLiteral("%1(%2)").arg(field).arg(fields.join(QLatin1Char(',')));
 }
 
 void Job::restart()
