@@ -104,6 +104,42 @@ class KGAPIDRIVE_EXPORT ChangeFetchJob : public KGAPI2::FetchJob
     qlonglong startChangeId() const;
     void setStartChangeId(qlonglong startChangeId);
 
+    /**
+     * @brief Whether both My Drive and shared drive items should be included in results.
+     *
+     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards shared drive items will be included in the results.
+     */
+    KGAPIDRIVE_DEPRECATED bool includeItemsFromAllDrives() const;
+
+    /**
+     * @brief Sets whether both My Drive and shared drive items should be included in results.
+     *
+     * Set to true by default as LibKGAPI supports Team Drives.
+     *
+     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards shared drive items will be included in the results.
+     */
+    KGAPIDRIVE_DEPRECATED void setIncludeItemsFromAllDrives(bool includeItemsFromAllDrives);
+
+    /**
+     * @brief Whether the request supports both My Drives and shared drives.
+     *
+     * Set to true by default as LibKGAPI supports Team Drives.
+     *
+     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards all applications
+     * are assumed to support shared drives.
+     */
+    KGAPIDRIVE_DEPRECATED bool supportsAllDrives() const;
+
+    /**
+     * @brief Sets whether the request supports both My Drives and shared drives.
+     *
+     * Set to true by default as LibKGAPI supports Team Drives.
+     *
+     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards all applications
+     * are assumed to support shared drives.
+     */
+    KGAPIDRIVE_DEPRECATED void setSupportsAllDrives(bool supportsAllDrives);
+
   protected:
     void start() override;
     KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
